.. start-include

=======
ming_p1
=======

.. image:: https://travis-ci.org/mingder78/ming-p1.svg?branch=master
   :target: https://travis-ci.org/mingder78/ming-p1
   :alt: Build status: Linux and OSX

.. image:: https://ci.appveyor.com/api/projects/status/github/mingder78/ming-p1?branch=master&svg=true
   :target: https://ci.appveyor.com/project/mingder78/ming-p1
   :alt: Build status: Windows

.. image:: https://readthedocs.org/projects/ming-p1/badge/?version=latest
   :target: https://ming-p1.readthedocs.io/
   :alt: Documentation status

.. image:: https://img.shields.io/pypi/v/ming_p1.svg
   :target: https://pypi.org/project/ming_p1/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/pyversions/ming_p1.svg
   :target: https://pypi.org/project/ming_p1/
   :alt: Python versions supported

.. end-include
